@@ -1,7 +1,7 @@
 package App::CompleteCLIs;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-18'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,10 +22,69 @@ App::CompleteCLIs - CLI wrappers for complete_*() functions
 
 =head1 VERSION
 
-This document describes version 0.05 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2015-09-09.
+This document describes version 0.06 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2015-09-18.
 
 =head1 SYNOPSIS
 
+=head1 DESCRIPTION
+
+This distribution comes with the following CLI's from the various C<Complete::*>
+modules:
+
+=over
+
+=item * L<complete-array-elem>
+
+=item * L<complete-dist>
+
+=item * L<complete-dzil-bundle>
+
+=item * L<complete-dzil-plugin>
+
+=item * L<complete-dzil-role>
+
+=item * L<complete-env>
+
+=item * L<complete-file>
+
+=item * L<complete-float>
+
+=item * L<complete-gid>
+
+=item * L<complete-group>
+
+=item * L<complete-hash-key>
+
+=item * L<complete-int>
+
+=item * L<complete-manpage>
+
+=item * L<complete-module>
+
+=item * L<complete-pid>
+
+=item * L<complete-proc-name>
+
+=item * L<complete-program>
+
+=item * L<complete-riap-url>
+
+=item * L<complete-tz>
+
+=item * L<complete-uid>
+
+=item * L<complete-user>
+
+=item * L<complete-weaver-bundle>
+
+=item * L<complete-weaver-plugin>
+
+=item * L<complete-weaver-role>
+
+=item * L<complete-weaver-section>
+
+=back
+
 =head1 SEE ALSO
 
 L<Complete>
